@@ -23,12 +23,15 @@
 
 #include <config.h>
 #include <string.h>
+#include <stdlib.h>
+
+#include <gdk/gdkkeysyms.h>
+
 
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
+
 #include <panel-applet.h>
 #include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include "mini-commander_applet.h"
 #include "preferences.h"
 #include "command_line.h"
@@ -40,7 +43,7 @@
 
 #define COMMANDLINE_BROWSER_STOCK "commandline-browser"
 #define COMMANDLINE_HISTORY_STOCK "commandline-history"
- 
+
 #define COMMANDLINE_DEFAULT_ICON_SIZE 6
 
 static gboolean icons_initialized = FALSE;
@@ -85,7 +88,7 @@ register_command_line_stock_icons (GtkIconFactory *factory)
 }
 
 static void
-command_line_init_stock_icons ()
+command_line_init_stock_icons (void)
 {
 
     GtkIconFactory *factory;
@@ -111,9 +114,9 @@ void
 set_atk_name_description (GtkWidget  *widget,
 			  const char *name,
 			  const char *description)
-{	
+{
     AtkObject *aobj;
-	
+
     aobj = gtk_widget_get_accessible (widget);
     if (GTK_IS_ACCESSIBLE (aobj) == FALSE)
         return;
@@ -155,7 +158,7 @@ send_button_to_entry_event (GtkWidget *widget, GdkEventButton *event, MCData *mc
 static gboolean
 key_press_cb (GtkWidget *widget, GdkEventKey *event, MCData *mc)
 {
-	switch (event->keyval) {	
+	switch (event->keyval) {
 	case GDK_b:
 		if (event->state == GDK_CONTROL_MASK) {
 			mc_show_file_browser (NULL, mc);
@@ -182,23 +185,24 @@ mc_applet_draw (MCData *mc)
     GtkWidget *icon;
     GtkWidget *button;
     GtkWidget *hbox_buttons;
-    GtkWidget *frame;
     MCPreferences prefs = mc->preferences;
     int        size_frames = 0;
     gchar     *command_text = NULL;
 
-    if (mc->preferences.show_frame)
-	size_frames += 6;
-
     if (mc->entry != NULL)
 	command_text = g_strdup (gtk_editable_get_chars (GTK_EDITABLE (mc->entry), 0, -1));
 
-    mc->cmd_line_size_y = mc->preferences.normal_size_y - size_frames;   
+    mc->cmd_line_size_y = mc->preferences.normal_size_y - size_frames;
 
     if (mc->applet_box) {
-        gtk_widget_destroy (mc->applet_box);	
+        gtk_widget_destroy (mc->applet_box);
     }
-    mc->applet_box = gtk_hbox_new (FALSE, 0);
+
+    if ( ((mc->orient == PANEL_APPLET_ORIENT_LEFT) || (mc->orient == PANEL_APPLET_ORIENT_RIGHT)) && (prefs.panel_size_x < GNOME_Vertigo_PANEL_SMALL) )
+      mc->applet_box = gtk_vbox_new (FALSE, 0);
+    else
+      mc->applet_box = gtk_hbox_new (FALSE, 0);
+
     gtk_container_set_border_width (GTK_CONTAINER (mc->applet_box), 0);
 
     mc_create_command_entry (mc);
@@ -209,32 +213,38 @@ mc_applet_draw (MCData *mc)
     }
 
     /* hbox for message label and buttons */
-    if (prefs.normal_size_y > GNOME_Vertigo_PANEL_X_SMALL) 
+    if ((mc->orient == PANEL_APPLET_ORIENT_LEFT) || (mc->orient == PANEL_APPLET_ORIENT_RIGHT))
+      if (prefs.panel_size_x < GNOME_Vertigo_PANEL_SMALL)
 	hbox_buttons = gtk_vbox_new (TRUE, 0);
+      else
+	hbox_buttons = gtk_hbox_new (TRUE, 0);
     else
+      if (prefs.normal_size_y > GNOME_Vertigo_PANEL_SMALL)
+	hbox_buttons = gtk_vbox_new (TRUE, 0);
+      else
 	hbox_buttons = gtk_hbox_new (TRUE, 0);
 
     /* add file-browser button */
     button = gtk_button_new ();
-    
+
     g_signal_connect (button, "clicked",
 		      G_CALLBACK (mc_show_file_browser), mc);
     g_signal_connect (button, "button_press_event",
 		      G_CALLBACK (button_press_hack), mc);
 
-    icon = gtk_image_new_from_stock (COMMANDLINE_BROWSER_STOCK,   								      button_icon_size);
+    icon = gtk_image_new_from_stock (COMMANDLINE_BROWSER_STOCK, button_icon_size);
     gtk_container_add (GTK_CONTAINER (button), icon);
 
-    gtk_tooltips_set_tip (mc->tooltips, button, _("Browser"), NULL);
+    gtk_widget_set_tooltip_text (button, _("Browser"));
     gtk_box_pack_start (GTK_BOX (hbox_buttons), button, TRUE, TRUE, 0);
-	
+
     set_atk_name_description (button,
 			      _("Browser"),
 			      _("Click this button to start the browser"));
 
     /* add history button */
     button = gtk_button_new ();
-    
+
     g_signal_connect (button, "clicked",
 		      G_CALLBACK (mc_show_history), mc);
     g_signal_connect (button, "button_press_event",
@@ -243,63 +253,18 @@ mc_applet_draw (MCData *mc)
     icon = gtk_image_new_from_stock (COMMANDLINE_HISTORY_STOCK, 								     button_icon_size);
     gtk_container_add (GTK_CONTAINER (button), icon);
 
-    gtk_tooltips_set_tip (mc->tooltips, button, _("History"), NULL);
+    gtk_widget_set_tooltip_text (button, _("History"));
     gtk_box_pack_end (GTK_BOX (hbox_buttons), button, TRUE, TRUE, 0);
 
     set_atk_name_description (button,
 			      _("History"),
 			      _("Click this button for the list of previous commands"));
-    
 
-    if (mc->preferences.show_handle) {
-	GtkWidget *handle;
-	GtkWidget *hbox;
+    gtk_box_pack_start (GTK_BOX (mc->applet_box), mc->entry, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (mc->applet_box), hbox_buttons, TRUE, TRUE, 0);
 
-	/* add a handle box to allow moving away this appplet from the panel */
-	handle = gtk_handle_box_new ();
-	gtk_box_pack_start (GTK_BOX (mc->applet_box), handle, TRUE, TRUE, 0);
-	
-	hbox = gtk_hbox_new (FALSE, 2);
-	
-	if (mc->preferences.show_frame) {
-	    
-	    frame = gtk_frame_new (NULL);
-	    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-	    gtk_container_add (GTK_CONTAINER (handle), frame);
-	    gtk_container_add (GTK_CONTAINER (frame), hbox);
-
-	    gtk_box_pack_start (GTK_BOX (hbox), mc->entry, TRUE, TRUE, 0);
-	    gtk_box_pack_start (GTK_BOX (hbox), hbox_buttons, TRUE, TRUE, 0);
-	} else {
-	    gtk_container_add (GTK_CONTAINER (handle), hbox);
-	    gtk_box_pack_start (GTK_BOX (hbox), mc->entry, TRUE, TRUE, 0);
-	    gtk_box_pack_start (GTK_BOX (hbox), hbox_buttons, TRUE, TRUE, 0);
-	}
-    } else {
-        GtkWidget *hbox;
-        
-        hbox = gtk_hbox_new (FALSE, 2);
-        gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
-	if (mc->preferences.show_frame) {
-	   
-  	    frame = gtk_frame_new (NULL);
-	    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-	    gtk_box_pack_start (GTK_BOX (mc->applet_box), frame, TRUE, TRUE, 0);
-	    gtk_container_add (GTK_CONTAINER (frame), hbox);
-		    
-	    gtk_box_pack_start (GTK_BOX (hbox), mc->entry, TRUE, TRUE, 0);
-	    gtk_box_pack_start (GTK_BOX (hbox), hbox_buttons, TRUE, TRUE, 0);
-	
-	} else {
-	    gtk_box_pack_start (GTK_BOX (mc->applet_box), hbox, TRUE, TRUE, 0);
-	    gtk_box_pack_start (GTK_BOX (hbox), mc->entry, TRUE, TRUE, 0);
-	    gtk_box_pack_start (GTK_BOX (hbox), hbox_buttons, TRUE, TRUE, 0);
-	}
-    }
-
-    
     gtk_container_add (GTK_CONTAINER (mc->applet), mc->applet_box);
-    
+
     gtk_widget_show_all (mc->applet_box);
 }
 
@@ -317,13 +282,8 @@ mc_destroyed (GtkWidget *widget,
     }
     g_object_unref (client);
 
-    g_object_unref (mc->tooltips);	
-
     mc_macros_free (mc->preferences.macros);
 
-    if (mc->about_dialog)
-        gtk_widget_destroy (mc->about_dialog);
-
     if (mc->prefs_dialog.dialog)
         gtk_widget_destroy (mc->prefs_dialog.dialog);
 
@@ -332,18 +292,35 @@ mc_destroyed (GtkWidget *widget,
 
     if (mc->file_select)
         gtk_widget_destroy (mc->file_select);
-    
+
     g_free (mc);
 }
 
+static void
+mc_orient_changed (PanelApplet *applet,
+		   PanelAppletOrient orient,
+		   MCData *mc)
+{
+  mc->orient = orient;
+  mc_applet_draw (mc);
+}
+
 static void
 mc_pixel_size_changed (PanelApplet *applet,
-		       guint        size,
+		       GtkAllocation *allocation,
 		       MCData      *mc)
 {
-    mc->preferences.normal_size_y = size;
+  if ((mc->orient == PANEL_APPLET_ORIENT_LEFT) || (mc->orient == PANEL_APPLET_ORIENT_RIGHT)) {
+    if (mc->preferences.panel_size_x == allocation->width)
+      return;
+    mc->preferences.panel_size_x = allocation->width;
+  } else {
+    if (mc->preferences.normal_size_y == allocation->height)
+      return;
+    mc->preferences.normal_size_y = allocation->height;
+  }
 
-    mc_applet_draw (mc);
+  mc_applet_draw (mc);
 }
 
 static gboolean
@@ -375,9 +352,10 @@ mini_commander_applet_fill (PanelApplet *applet)
 	    exit (1);
     }
 
-    
-    gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/gnome-mini-commander.png");
-    
+    g_set_application_name (_("Command Line"));
+
+    gtk_window_set_default_icon_name ("gnome-mini-commander");
+
     mc = g_new0 (MCData, 1);
     mc->applet = applet;
 
@@ -386,26 +364,24 @@ mini_commander_applet_fill (PanelApplet *applet)
     mc_load_preferences (mc);
     command_line_init_stock_icons ();
 
-    mc->about_dialog = NULL;
-
-    mc->tooltips = gtk_tooltips_new ();
-    g_object_ref (mc->tooltips);
-    gtk_object_sink (GTK_OBJECT (mc->tooltips));
-  
-    g_signal_connect (mc->applet, "change_size",
+    g_signal_connect (mc->applet, "change_orient",
+		      G_CALLBACK (mc_orient_changed), mc);
+    g_signal_connect (mc->applet, "size_allocate",
 		      G_CALLBACK (mc_pixel_size_changed), mc);
-    mc_pixel_size_changed (mc->applet, panel_applet_get_size (applet), mc);
 
+    mc->preferences.normal_size_y = panel_applet_get_size (applet);
+    mc->orient = panel_applet_get_orient (applet);
+    mc_applet_draw(mc);
     gtk_widget_show (GTK_WIDGET (mc->applet));
-    
-    g_signal_connect (mc->applet, "destroy", G_CALLBACK (mc_destroyed), mc); 
+
+    g_signal_connect (mc->applet, "destroy", G_CALLBACK (mc_destroyed), mc);
     g_signal_connect (mc->applet, "button_press_event",
 		      G_CALLBACK (send_button_to_entry_event), mc);
     g_signal_connect (mc->applet, "key_press_event",
 		      G_CALLBACK (key_press_cb), mc);
 
     panel_applet_setup_menu_from_file (mc->applet,
-				       NULL,
+				       DATADIR,
 				       "GNOME_MiniCommanderApplet.xml",
 				       NULL,
 				       mini_commander_menu_verbs,
@@ -425,7 +401,7 @@ mini_commander_applet_fill (PanelApplet *applet)
     set_atk_name_description (GTK_WIDGET (applet),
 			      _("Mini-Commander applet"),
 			      _("This applet adds a command line to the panel"));
-    
+
     return TRUE;
 }
 
@@ -437,8 +413,8 @@ mini_commander_applet_factory (PanelApplet *applet,
         gboolean retval = FALSE;
 
         if (!strcmp (iid, "OAFIID:GNOME_MiniCommanderApplet"))
-                retval = mini_commander_applet_fill(applet); 
-    
+                retval = mini_commander_applet_fill(applet);
+
         return retval;
 }
 
